@@ -303,7 +303,11 @@
 						}
 						// click marker
 						var clickMarker = function(e) {
-							window.location.href = this.options.clickURL;
+							if (data.mapLinksTarget) {
+								window.open(this.options.clickURL, data.mapLinksTarget);
+							} else {
+								window.location.href = this.options.clickURL;
+							}
 						}
 
 						if (markers) {
